@@ -4,11 +4,13 @@
 import os
 import tempfile
 import argparse
+import sys
 
 from robin_sd_upload import _version
 from robin_sd_upload.slack_interaction import slack_handler
 from robin_sd_upload.supportive_scripts import yaml_parser
 from robin_sd_upload.supportive_scripts import logger
+from robin_sd_upload.supportive_scripts import version_checker
 
 from robin_sd_upload.api_interaction import push_software
 from robin_sd_upload.supportive_scripts import check_upload_file
@@ -32,7 +34,7 @@ def arg_parser():
 
     # arguments for upload
     parser.add_argument('-t', "--type", type=str, help="radar type")
-    parser.add_argument("-n", "--number", type=str, help="version number of the software")
+    parser.add_argument('-n', "--number", type=str, help="version number of the software")
     parser.add_argument('-p', "--path", type=str, help="upload file absolute path")
 
     args = parser.parse_args()
@@ -42,27 +44,25 @@ def arg_parser():
     logger.log(message="Version: " + _version.__version__, log_level="info", to_file=True, to_terminal=True)
     logger.log(message="Username: " + config['robin_email'], log_level="info", to_file=True, to_terminal=True)
 
+    version_checker.check_latest_version()
+
     radarType = args.type
     version_name = args.number
     upload_file_path = args.path
 
-    # print('radarType: ', radarType)
-    # print('version_name: ', version_name)
-    # print('upload_file_path: ', upload_file_path)
-
     if args.check:
-        # check if all the prerequisites are met
+        check_upload_file.check_upload_file(upload_file_path, version_name)
         logger.log(message="All prerequisites met.", log_level="info", to_file=True, to_terminal=True)
-        exit(0)
+        sys.exit(0)
     elif args.upload:
         if radarType is None or version_name is None or upload_file_path is None:
             print('Please provide all the arguments: --type, --version, --path')
-            exit(1)
+            sys.exit(1)
 
         # check if the radar type is valid
         validate.validate(radarType, version_name)
         if check_upload_file.check_upload_file(upload_file_path, version_name) is False:
-            exit(1)
+            sys.exit(1)
         
         # create a temp folder and zip the file
         temp_dir = tempfile.mkdtemp()
@@ -71,16 +71,13 @@ def arg_parser():
         create_zip.create_zip(upload_file_path + '/' + version_name, temp_dir, version_name)
         push_software.push_software(zipped_file_path, radarType, version_name)
         remove_zip.remove_zip(zipped_file_path)
-        exit(0)
+        sys.exit(0)
+
     elif args.slack:
         slack_handler.send_slack_entrypoint()
         logger.log(message="Slack message sent successfully.", log_level="info", to_file=True, to_terminal=True)
-        exit(0)
+        sys.exit(0)
+
     else:
         parser.print_help()
-        exit(1)
-
-
-
-
-
+        sys.exit(1)
